/*
   Copyright (c) 2016 Sandro Knauß <sknauss@kde.org>

   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   This library is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
   License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
   02110-1301, USA.
*/

#include "multipartalternative.h"

#include "utils.h"

#include "objecttreeparser.h"
#include "messagepart.h"

#include <KMime/Content>

#include "mimetreeparser_debug.h"

using namespace MimeTreeParser;

const MultiPartAlternativeBodyPartFormatter *MultiPartAlternativeBodyPartFormatter::self;

const Interface::BodyPartFormatter *MultiPartAlternativeBodyPartFormatter::create()
{
    if (!self) {
        self = new MultiPartAlternativeBodyPartFormatter();
    }
    return self;
}

MessagePart::Ptr MultiPartAlternativeBodyPartFormatter::process(Interface::BodyPart &part) const
{
    KMime::Content *node = part.content();
    if (node->contents().isEmpty()) {
        return MessagePart::Ptr();
    }

    auto preferredMode = part.source()->preferredMode();
    AlternativeMessagePart::Ptr mp(new AlternativeMessagePart(part.objectTreeParser(), node, preferredMode));
    if (mp->childParts().isEmpty()) {
        MimeMessagePart::Ptr _mp(new MimeMessagePart(part.objectTreeParser(), node->contents().at(0), false));
        return _mp;
    }

    KMime::Content *dataIcal = mp->childParts().contains(Util::MultipartIcal) ? mp->childParts()[Util::MultipartIcal]->content() : nullptr;
    KMime::Content *dataHtml = mp->childParts().contains(Util::MultipartHtml) ? mp->childParts()[Util::MultipartHtml]->content() : nullptr;
    KMime::Content *dataPlain = mp->childParts().contains(Util::MultipartPlain) ? mp->childParts()[Util::MultipartPlain]->content() : nullptr;

    // Make sure that in default ical is preferred over html and plain text
    if (dataIcal && ((preferredMode != Util::MultipartHtml && preferredMode != Util::MultipartPlain))) {
        if (dataHtml) {
            part.nodeHelper()->setNodeProcessed(dataHtml, false);
        }
        if (dataPlain) {
            part.nodeHelper()->setNodeProcessed(dataPlain, false);
        }
        preferredMode = Util::MultipartIcal;
    } else if ((dataHtml && (preferredMode == Util::MultipartHtml || preferredMode == Util::Html))
               || (dataHtml && dataPlain && dataPlain->body().isEmpty())) {
        if (dataPlain) {
            part.nodeHelper()->setNodeProcessed(dataPlain, false);
        }
        preferredMode = Util::MultipartHtml;
    } else if (!(preferredMode == Util::MultipartHtml) && dataPlain) {
        part.nodeHelper()->setNodeProcessed(dataHtml, false);
        preferredMode = Util::MultipartPlain;
    }

//    qDebug() << " MessagePart::Ptr MultiPartAlternativeBodyPartFormatter::process(Interface::BodyPart &part) const";
//    for (int i = 0; i < mp->availableModes().count(); ++i) {
//        qDebug() << "MultiPartAlternativeBodyPartFormatter::processed Modes " << MimeTreeParser::Util::htmlModeToString(mp->availableModes().at(i));
//    }
//    qDebug() << "MultiPartAlternativeBodyPartFormatter::process preferred " << MimeTreeParser::Util::htmlModeToString(preferredMode);

    part.source()->setHtmlMode(preferredMode, mp->availableModes());
    mp->setPreferredMode(preferredMode);
    return mp;
}
